from .albarans import Albarans
from .articles import Articles
from .clients import Clients
from .tercers import Tercers
from .repartidors import Repartidors
from .comandes import Comandes
from .pobles import Pobles
from .provincies import Provincies
from .portals_web import PortalsWeb
from .regularitzacions import Regularitzacions
from .usuaris import Usuaris
from .wms import Wms
from .magatzems import Magatzems
